# InvoiceScheduleItemStatus

The status of the invoice schedule item. 

## Enum

* `PENDING` (value: `'Pending'`)

* `EXECUTING` (value: `'Executing'`)

* `PROCESSED` (value: `'Processed'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


